from zope.interface import implements
from Products.Five import BrowserView

from collective.browserdetector.interfaces import IBrowserDetector
from collective.browserdetector.i18n import cbdMessageFactory as _

class BrowserDetector(BrowserView):
    """ A helper browser view to get user agent detection results"""

    implements(IBrowserDetector)

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self._prtc = self.request.get('SERVER_PROTOCOL', u'')
        self._ua_id = self.request.get('HTTP_USER_AGENT',
                                        u'Detection not supported')
        self._ua = self._ua_id.lower()

    @property
    def agent(self):
        return self._ua_id

    def protocol(self):
        if self.isSecure:
            return _(u"Secure (${protocol})", mapping={'protocol': self._prtc})
        return _(u"Unsecure (${protocol})", mapping={'protocol': self._prtc})
    
    def platform(self):
        if self.isMac:
            return u'Mac (OS X)'
        elif self.isLinux:
            return u'Linux'
        elif self.isWindows:
            return u'Microsoft Windows'
        else:
            return _(u'Unknown')
    
    def browser(self):
        if self.isSafari:
            if self.isSafari3:
                return u'Safari 3.x'
            elif self.isSafari4:
                return u'Safari 4.x'
            else:
                return u'Safari'
        elif self.isGecko:
            if self.isGecko2:
                return u'Mozilla/Firefox 2.x'
            elif self.isGecko3:
                return u'Mozilla/Firefox 3.x'
            else:
                return u'Mozilla/Firefox'
        elif self.isIE:
            if self.isIE6:
                return u'Internet Explorer 6.x'
            elif self.isIE7:
                return u'Internet Explorer 7.x'
            elif self.isIE8:
                return u'Internet Explorer 8.x'
            else:
                return u'Internet Explorer'
        elif self.isChrome:
            return u'Chrome'
        elif self.isOpera:
            return u'Opera'
        else:
            return _(u'Unknown')

    @property
    def true_icon(self):
        return self.context.unrestrictedTraverse('confirm_icon.gif').tag(title=_(u"Yes"))
    
    @property
    def false_icon(self):
        return self.context.unrestrictedTraverse('delete_icon.gif').tag(title=_(u"No"))
    
    @property
    def isSecure(self):
        return (self._prtc.find('https/') == 0)

    @property
    def isWebKit(self):
        return (self._ua.find('webkit') >= 0)

    @property
    def isOpera(self):
        return (self._ua.find('opera') >= 0)
    
    @property
    def isChrome(self):
        return (self._ua.find('chrome') >= 0)

    @property
    def isSafari(self):
        return (not self.isChrome) and (self._ua.find('safari') >= 0)
    
    @property
    def isSafari3(self):
        return self.isSafari and (self._ua.find('version/3') > 0)
    
    @property
    def isSafari4(self):
        return self.isSafari and (self._ua.find('version/4') > 0)
    
    @property
    def isIE(self):
        return (not self.isOpera) and (self._ua.find('msie') >= 0)
    
    @property
    def isIE7(self):
        return self.isIE and (self._ua.find('msie 7') >= 0)
    
    @property
    def isIE8(self):
        return self.isIE and (self._ua.find('msie 8') >= 0)
    
    @property
    def isIE6(self):
        return self.isIE and (not (self.isIE7 or self.isIE8))

    @property
    def isGecko(self):
        return (not self.isWebKit) and (self._ua.find('gecko') >= 0)
    
    @property
    def isGecko3(self):
        return self.isGecko and (self._ua.find('rv:1.9') > 0)
    
    @property
    def isGecko2(self):
        return self.isGecko and (not self.isGecko3)
    
    @property
    def isWindows(self):
        return (self._ua.find('windows') > 0) or (self._ua.find('win32') > 0)
    
    @property
    def isMac(self):
        return (self._ua.find('macintosh') > 0) or (self._ua.find('mac os x') > 0)
    
    @property
    def isLinux(self):
        return (self._ua.find('linux') > 0)

    @property
    def isSafariOnMac(self):
        return (self.isMac and self.isSafari)
    
    @property
    def isSafariOnWin(self):
        return (self.isWindows and self.isSafari)
    
    @property
    def isGeckoOnMac(self):
        return (self.isMac and self.isGecko)
    
    @property
    def isGeckoOnLinux(self):
        return (self.isLinux and self.isGecko)
    
    @property
    def isGeckoOnWin(self):
        return (self.isWindows and self.isGecko)
    
    @property
    def isOperaOnMac(self):
        return (self.isMac and self.isOpera)
    
    @property
    def isOperaOnLinux(self):
        return (self.isLinux and self.isOpera)
    
    @property
    def isOperaOnWin(self):
        return (self.isWindows and self.isOpera)
    
    @property
    def isChromeOnMac(self):
        return (self.isMac and self.isChrome)
    
    @property
    def isChromeOnLinux(self):
        return (self.isLinux and self.isChrome)
    
    @property
    def isChromeOnWin(self):
        return (self.isWin and self.isChrome)



from zope.interface import Interface
from zope.interface import implements
from zope.component import getMultiAdapter

from plone.app.portlets.portlets import base
from plone.portlets.interfaces import IPortletDataProvider

from zope import schema
from zope.formlib import form
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile

from collective.browserdetector.i18n import cbdMessageFactory as _

class IBrowserDetector(IPortletDataProvider):
    """A portlet

    It inherits from IPortletDataProvider because for this portlet, the
    data that is being rendered and the portlet assignment itself are the
    same.
    """

class Assignment(base.Assignment):
    """Portlet assignment.

    This is what is actually managed through the portlets UI and associated
    with columns.
    """

    implements(IBrowserDetector)

    def __init__(self):
        pass

    @property
    def title(self):
        """This property is used to give the title of the portlet in the
        "manage portlets" screen.
        """
        return _(u"Browser Detector")


class Renderer(base.Renderer):
    """Portlet renderer.

    This is registered in configure.zcml. The referenced page template is
    rendered, and the implicit variable 'view' will refer to an instance
    of this class. Other methods can be added and referenced in the template.
    """

    render = ViewPageTemplateFile('browserdetector.pt')
    
    def detector(self):
        return getMultiAdapter((self.context, self.request), name=u'browser-detector')


class AddForm(base.NullAddForm):
    """Portlet add form.

    This is registered in configure.zcml. The form_fields variable tells
    zope.formlib which fields to display. The create() method actually
    constructs the assignment that is being added.
    """

    def create(self):
        return Assignment()





from zope.interface import Interface, Attribute

class IBrowserDetector(Interface):
    """ A browser agent detector view """
    
    agent = Attribute("User Agent")
    protocol = Attribute("Protocol type")
    platform = Attribute("Browser Platform")
    browser = Attribute("Browser type/version")
    true_icon = Attribute("True icon")
    false_icon = Attribute("False icon")
    
    isSecure = Attribute("True if secure protocol is in use")
    isWebKit = Attribute("True if a WebKit based browser has been detected")
    
    isOpera = Attribute("True if an Opera browser has been detected")
    isChrome = Attribute("True if a Chrome browser has been detected")

    isSafari = Attribute("True if a Safari browser has been detected")
    isSafari3 = Attribute("True if a Safari browser of version 3.x has been detected")
    isSafari4 = Attribute("True if a Safari browser of version 4.x has been detected")
    
    isIE = Attribute("True if a Internet Explorer browser has been detected")
    isIE7 = Attribute("True if a Internet Explorer browser of version 7.x has been detected")
    isIE8 = Attribute("True if a Internet Explorer browser of version 8.x has been detected")
    isIE6 = Attribute("True if a Internet Explorer browser of version 6.x has been detected")

    isGecko = Attribute("True if a Mozilla/Firefox browser has been detected")
    isGecko3 = Attribute("True if a Mozilla/Firefox browser of version 3.x has been detected")
    isGecko2 = Attribute("True if a Mozilla/Firefox browser of version 2.x has been detected")
    
    isWindows = Attribute("True if a Windows platform has been detected")
    isMac = Attribute("True if a Mac platform has been detected")
    isLinux = Attribute("True if a Linux platform has been detected")
    
    isSafariOnMac = Attribute("True if a Safari browser on Mac has been detected")
    isSafariOnWin = Attribute("True if a Safari browser on Windows has been detected")
    
    isGeckoOnMac = Attribute("True if a Gecko browser on Mac has been detected")
    isGeckoOnLinux = Attribute("True if a Gecko browser on Linux has been detected")
    isGeckoOnWin = Attribute("True if a Gecko on Windows browser has been detected")
    
    isOperaOnMac = Attribute("True if a Opera browser on Mac has been detected")
    isOperaOnLinux = Attribute("True if a Opera browser on Linux has been detected")
    isOperaOnWin = Attribute("True if a Opera browser on Windows has been detected")
    
    isChromeOnMac = Attribute("True if a Chrome browser on Mac has been detected")
    isChromeOnLinux = Attribute("True if a Chrome browser on Linux has been detected")
    isChromeOnWin = Attribute("True if a Chrome browser on Windows has been detected")
